# coding: utf-8

# flake8: noqa
"""
    Visier Administration APIs

    Visier APIs for managing your tenant or tenants in Visier. You can programmatically manage user accounts in Visier, the profiles and permissions assigned to users, and to make changes in projects and publish projects to production. Administrating tenant users can use administration APIs to manage their analytic tenants and consolidated analytics tenants.<br>**Note:** If you submit API requests for changes that cause a project to publish to production (such as assigning permissions to users or updating permissions), each request is individually published to production, resulting in hundreds or thousands of production versions. We recommend that you use the `ProjectID` request header to make changes in a project, if `ProjectID` is available for the API endpoint.

    The version of the OpenAPI document: 22222222.99201.1497
    Contact: alpine@visier.com

    Please note that this SDK is currently in beta.
    Functionality and behavior may change in future releases.
    We encourage you to provide feedback and report any issues encountered during your use.
"""  # noqa: E501


# import models into model package
from visier_api_administration.models.accessible_tenant_profile_assignment_request_dto import AccessibleTenantProfileAssignmentRequestDTO
from visier_api_administration.models.accessible_tenant_profile_assignment_response_dto import AccessibleTenantProfileAssignmentResponseDTO
from visier_api_administration.models.accessible_tenant_profile_revoke_request_dto import AccessibleTenantProfileRevokeRequestDTO
from visier_api_administration.models.accessible_tenant_profile_revoke_response_dto import AccessibleTenantProfileRevokeResponseDTO
from visier_api_administration.models.additional_capabilities_dto import AdditionalCapabilitiesDTO
from visier_api_administration.models.admin_capability_config_dto import AdminCapabilityConfigDTO
from visier_api_administration.models.all_permissions_assigned_for_local_tenant_dto import AllPermissionsAssignedForLocalTenantDTO
from visier_api_administration.models.all_profile_assigned_for_accessible_tenant_dto import AllProfileAssignedForAccessibleTenantDTO
from visier_api_administration.models.all_profile_assigned_for_local_tenant_dto import AllProfileAssignedForLocalTenantDTO
from visier_api_administration.models.all_tenants_status_apidto import AllTenantsStatusAPIDTO
from visier_api_administration.models.all_user_groups_assigned_for_local_tenant_dto import AllUserGroupsAssignedForLocalTenantDTO
from visier_api_administration.models.all_users_get_api_response_dto import AllUsersGetAPIResponseDTO
from visier_api_administration.models.analytic_object_dto import AnalyticObjectDTO
from visier_api_administration.models.assign_revoke_permission_by_permission_dto import AssignRevokePermissionByPermissionDTO
from visier_api_administration.models.assign_revoke_permission_by_tenant_dto import AssignRevokePermissionByTenantDTO
from visier_api_administration.models.assign_revoke_permission_by_user_dto import AssignRevokePermissionByUserDTO
from visier_api_administration.models.assign_revoke_permission_request_dto import AssignRevokePermissionRequestDTO
from visier_api_administration.models.assign_revoke_permissions_request_dto import AssignRevokePermissionsRequestDTO
from visier_api_administration.models.assign_revoke_permissions_response_dto import AssignRevokePermissionsResponseDTO
from visier_api_administration.models.bulk_data_access_set_response_dto import BulkDataAccessSetResponseDTO
from visier_api_administration.models.business_location_dto import BusinessLocationDTO
from visier_api_administration.models.capabilities_dto import CapabilitiesDTO
from visier_api_administration.models.capability_dto import CapabilityDTO
from visier_api_administration.models.commit_and_publish_operation_response_dto import CommitAndPublishOperationResponseDTO
from visier_api_administration.models.commit_dto import CommitDTO
from visier_api_administration.models.consolidated_analytics_api_excluded_source_list_dto import ConsolidatedAnalyticsAPIExcludedSourceListDTO
from visier_api_administration.models.consolidated_analytics_api_source_tenant_list_dto import ConsolidatedAnalyticsAPISourceTenantListDTO
from visier_api_administration.models.consolidated_analytics_api_tenant_create_request_dto import ConsolidatedAnalyticsAPITenantCreateRequestDTO
from visier_api_administration.models.consolidated_analytics_api_tenant_list_response_dto import ConsolidatedAnalyticsAPITenantListResponseDTO
from visier_api_administration.models.consolidated_analytics_api_tenant_with_details import ConsolidatedAnalyticsAPITenantWithDetails
from visier_api_administration.models.consolidated_analytics_api_tenant_with_details_list_response_dto import ConsolidatedAnalyticsAPITenantWithDetailsListResponseDTO
from visier_api_administration.models.content_package_dto import ContentPackageDTO
from visier_api_administration.models.create_data_access_set_request_dto import CreateDataAccessSetRequestDTO
from visier_api_administration.models.custom_property_dto import CustomPropertyDTO
from visier_api_administration.models.custom_tenant_property_dto import CustomTenantPropertyDTO
from visier_api_administration.models.data_access_set_dto import DataAccessSetDTO
from visier_api_administration.models.data_access_set_error_dto import DataAccessSetErrorDTO
from visier_api_administration.models.data_access_set_failure_dto import DataAccessSetFailureDTO
from visier_api_administration.models.data_access_set_success_dto import DataAccessSetSuccessDTO
from visier_api_administration.models.data_security_profile_dto import DataSecurityProfileDTO
from visier_api_administration.models.delete_permissions_request_dto import DeletePermissionsRequestDTO
from visier_api_administration.models.delete_user_group_v2_request import DeleteUserGroupV2Request
from visier_api_administration.models.dimension_filter_dto import DimensionFilterDTO
from visier_api_administration.models.dynamic_dimension_filter_dto import DynamicDimensionFilterDTO
from visier_api_administration.models.dynamic_property_mapping_dto import DynamicPropertyMappingDTO
from visier_api_administration.models.element_ids_dto import ElementIDsDTO
from visier_api_administration.models.error_dto import ErrorDTO
from visier_api_administration.models.excluded_sources_body import ExcludedSourcesBody
from visier_api_administration.models.export_production_versions_api_operation_parameters_dto import ExportProductionVersionsAPIOperationParametersDTO
from visier_api_administration.models.failed_accessible_tenant_profile_assignment_dto import FailedAccessibleTenantProfileAssignmentDTO
from visier_api_administration.models.failed_local_tenant_profile_assignment_dto import FailedLocalTenantProfileAssignmentDTO
from visier_api_administration.models.failed_local_tenant_profile_revoke_dto import FailedLocalTenantProfileRevokeDTO
from visier_api_administration.models.get_capabilities_api_response_dto import GetCapabilitiesAPIResponseDTO
from visier_api_administration.models.get_content_packages_api_response_dto import GetContentPackagesAPIResponseDTO
from visier_api_administration.models.get_data_access_sets_api_response_dto import GetDataAccessSetsAPIResponseDTO
from visier_api_administration.models.get_data_security_objects_api_response_dto import GetDataSecurityObjectsAPIResponseDTO
from visier_api_administration.models.get_permissions_api_response_dto import GetPermissionsAPIResponseDTO
from visier_api_administration.models.get_production_versions_api_response_dto import GetProductionVersionsAPIResponseDTO
from visier_api_administration.models.get_projects_api_response_dto import GetProjectsAPIResponseDTO
from visier_api_administration.models.google_protobuf_any import GoogleProtobufAny
from visier_api_administration.models.hierarchy_property_dto import HierarchyPropertyDTO
from visier_api_administration.models.home_analysis_by_user_group_dto import HomeAnalysisByUserGroupDTO
from visier_api_administration.models.inherited_access_config_dto import InheritedAccessConfigDTO
from visier_api_administration.models.inherited_reference_member_filter_config_dto import InheritedReferenceMemberFilterConfigDTO
from visier_api_administration.models.last_login_dto import LastLoginDTO
from visier_api_administration.models.local_tenant_profile_assignment_request_dto import LocalTenantProfileAssignmentRequestDTO
from visier_api_administration.models.local_tenant_profile_assignment_response_dto import LocalTenantProfileAssignmentResponseDTO
from visier_api_administration.models.local_tenant_profile_revoke_request_dto import LocalTenantProfileRevokeRequestDTO
from visier_api_administration.models.local_tenant_profile_revoke_response_dto import LocalTenantProfileRevokeResponseDTO
from visier_api_administration.models.mask_message import MaskMessage
from visier_api_administration.models.member_filter_config_dto import MemberFilterConfigDTO
from visier_api_administration.models.member_selection_dto import MemberSelectionDTO
from visier_api_administration.models.metric_validation_summary_dto import MetricValidationSummaryDTO
from visier_api_administration.models.module_settings_dto import ModuleSettingsDTO
from visier_api_administration.models.permission_assigned_by_tenant_dto import PermissionAssignedByTenantDTO
from visier_api_administration.models.permission_assigned_for_local_tenant_dto import PermissionAssignedForLocalTenantDTO
from visier_api_administration.models.permission_assigned_user_dto import PermissionAssignedUserDTO
from visier_api_administration.models.permission_assigned_users_dto import PermissionAssignedUsersDTO
from visier_api_administration.models.permission_bulk_operation_response_dto import PermissionBulkOperationResponseDTO
from visier_api_administration.models.permission_dto import PermissionDTO
from visier_api_administration.models.permission_error_dto import PermissionErrorDTO
from visier_api_administration.models.permission_failure_dto import PermissionFailureDTO
from visier_api_administration.models.permission_response_dto import PermissionResponseDTO
from visier_api_administration.models.permission_success_dto import PermissionSuccessDTO
from visier_api_administration.models.permissions_list_dto import PermissionsListDTO
from visier_api_administration.models.permissions_to_user_group_for_tenant_dto import PermissionsToUserGroupForTenantDTO
from visier_api_administration.models.permissions_to_user_group_request_dto import PermissionsToUserGroupRequestDTO
from visier_api_administration.models.permissions_to_user_groups_request_dto import PermissionsToUserGroupsRequestDTO
from visier_api_administration.models.production_version_api_operation_response_dto import ProductionVersionAPIOperationResponseDTO
from visier_api_administration.models.production_versions_api_operation_request_dto import ProductionVersionsAPIOperationRequestDTO
from visier_api_administration.models.production_versions_api_operation_response_dto import ProductionVersionsAPIOperationResponseDTO
from visier_api_administration.models.profile_assigned_for_accessible_tenant_dto import ProfileAssignedForAccessibleTenantDTO
from visier_api_administration.models.profile_assigned_for_local_tenant_dto import ProfileAssignedForLocalTenantDTO
from visier_api_administration.models.profile_get_api_response_dto import ProfileGetAPIResponseDTO
from visier_api_administration.models.profiles_get_api_response_dto import ProfilesGetAPIResponseDTO
from visier_api_administration.models.project_commits_api_response_dto import ProjectCommitsAPIResponseDTO
from visier_api_administration.models.project_dto import ProjectDTO
from visier_api_administration.models.project_operation_request_dto import ProjectOperationRequestDTO
from visier_api_administration.models.project_operation_response_dto import ProjectOperationResponseDTO
from visier_api_administration.models.property_access_config_dto import PropertyAccessConfigDTO
from visier_api_administration.models.property_set_config_dto import PropertySetConfigDTO
from visier_api_administration.models.put_project_commits_request import PutProjectCommitsRequest
from visier_api_administration.models.reduced_error_dto import ReducedErrorDTO
from visier_api_administration.models.reduced_tenant_code_error_dto import ReducedTenantCodeErrorDTO
from visier_api_administration.models.reduced_user_id_error_dto import ReducedUserIdErrorDTO
from visier_api_administration.models.related_analytic_object_dto import RelatedAnalyticObjectDTO
from visier_api_administration.models.role_modules_config_dto import RoleModulesConfigDTO
from visier_api_administration.models.securable_dimension_dto import SecurableDimensionDTO
from visier_api_administration.models.securable_property_dto import SecurablePropertyDTO
from visier_api_administration.models.security_assignment_response_dto import SecurityAssignmentResponseDTO
from visier_api_administration.models.shareable_data_access_set import ShareableDataAccessSet
from visier_api_administration.models.simple_user_dto import SimpleUserDTO
from visier_api_administration.models.source_import_result_summary_dto import SourceImportResultSummaryDTO
from visier_api_administration.models.sources_api_operation_request_dto import SourcesAPIOperationRequestDTO
from visier_api_administration.models.sources_api_put_response_dto import SourcesAPIPutResponseDTO
from visier_api_administration.models.static_dimension_filter_dto import StaticDimensionFilterDTO
from visier_api_administration.models.status import Status
from visier_api_administration.models.successful_accessible_tenant_profile_assignment_dto import SuccessfulAccessibleTenantProfileAssignmentDTO
from visier_api_administration.models.successful_local_tenant_profile_assignment_dto import SuccessfulLocalTenantProfileAssignmentDTO
from visier_api_administration.models.system_status_dto import SystemStatusDTO
from visier_api_administration.models.target_project_for_tenant_dto import TargetProjectForTenantDTO
from visier_api_administration.models.target_project_for_tenants_list_dto import TargetProjectForTenantsListDTO
from visier_api_administration.models.target_tenant_code_dto import TargetTenantCodeDTO
from visier_api_administration.models.tenant_assignments_dto import TenantAssignmentsDTO
from visier_api_administration.models.tenant_code_body import TenantCodeBody
from visier_api_administration.models.tenant_code_error_dto import TenantCodeErrorDTO
from visier_api_administration.models.tenant_detail_apidto import TenantDetailAPIDTO
from visier_api_administration.models.tenant_management_api_get_response_dto import TenantManagementAPIGetResponseDTO
from visier_api_administration.models.tenant_management_api_list_response_dto import TenantManagementAPIListResponseDTO
from visier_api_administration.models.tenant_management_api_update_request_dto import TenantManagementAPIUpdateRequestDTO
from visier_api_administration.models.tenant_management_api_update_response_dto import TenantManagementAPIUpdateResponseDTO
from visier_api_administration.models.tenant_module_dto import TenantModuleDTO
from visier_api_administration.models.tenant_preview_entries_summary_dto import TenantPreviewEntriesSummaryDTO
from visier_api_administration.models.tenant_preview_entries_summary_list_dto import TenantPreviewEntriesSummaryListDTO
from visier_api_administration.models.tenant_provision_apidto import TenantProvisionAPIDTO
from visier_api_administration.models.tenant_status_apidto import TenantStatusAPIDTO
from visier_api_administration.models.update_tenant_model import UpdateTenantModel
from visier_api_administration.models.user_creation_api_request_dto import UserCreationAPIRequestDTO
from visier_api_administration.models.user_creation_api_response_dto import UserCreationAPIResponseDTO
from visier_api_administration.models.user_get_api_response_dto import UserGetAPIResponseDTO
from visier_api_administration.models.user_group_assigned_for_local_tenant_dto import UserGroupAssignedForLocalTenantDTO
from visier_api_administration.models.user_group_change_definition_dto import UserGroupChangeDefinitionDTO
from visier_api_administration.models.user_group_change_dimension_filter_dto import UserGroupChangeDimensionFilterDTO
from visier_api_administration.models.user_group_change_failure_dto import UserGroupChangeFailureDTO
from visier_api_administration.models.user_group_change_filter_dto import UserGroupChangeFilterDTO
from visier_api_administration.models.user_group_change_member_selection_dto import UserGroupChangeMemberSelectionDTO
from visier_api_administration.models.user_group_change_response_dto import UserGroupChangeResponseDTO
from visier_api_administration.models.user_group_change_success_dto import UserGroupChangeSuccessDTO
from visier_api_administration.models.user_group_change_users_dto import UserGroupChangeUsersDTO
from visier_api_administration.models.user_group_delete_dto import UserGroupDeleteDTO
from visier_api_administration.models.user_group_delete_failure_dto import UserGroupDeleteFailureDTO
from visier_api_administration.models.user_group_delete_response_dto import UserGroupDeleteResponseDTO
from visier_api_administration.models.user_group_delete_success_dto import UserGroupDeleteSuccessDTO
from visier_api_administration.models.user_group_filters_dto import UserGroupFiltersDTO
from visier_api_administration.models.user_group_get_api_response_dto import UserGroupGetAPIResponseDTO
from visier_api_administration.models.user_group_single_delete_response_dto import UserGroupSingleDeleteResponseDTO
from visier_api_administration.models.user_groups_change_dto import UserGroupsChangeDTO
from visier_api_administration.models.user_groups_delete_request_dto import UserGroupsDeleteRequestDTO
from visier_api_administration.models.user_groups_get_api_response_dto import UserGroupsGetAPIResponseDTO
from visier_api_administration.models.user_groups_users_dto import UserGroupsUsersDTO
from visier_api_administration.models.user_groups_users_for_tenant_dto import UserGroupsUsersForTenantDTO
from visier_api_administration.models.user_id_error_dto import UserIdErrorDTO
from visier_api_administration.models.user_property_dto import UserPropertyDTO
from visier_api_administration.models.user_security_assignments_dto import UserSecurityAssignmentsDTO
from visier_api_administration.models.user_update_api_request_dto import UserUpdateAPIRequestDTO
from visier_api_administration.models.users_api_error_message_dto import UsersAPIErrorMessageDTO
from visier_api_administration.models.users_api_failure_dto import UsersAPIFailureDTO
from visier_api_administration.models.users_api_response_dto import UsersAPIResponseDTO
from visier_api_administration.models.users_api_success_dto import UsersAPISuccessDTO
from visier_api_administration.models.users_creation_api_request_dto import UsersCreationAPIRequestDTO
from visier_api_administration.models.users_delete_api_request_dto import UsersDeleteAPIRequestDTO
from visier_api_administration.models.users_to_user_group_request_dto import UsersToUserGroupRequestDTO
from visier_api_administration.models.users_to_user_groups_request_dto import UsersToUserGroupsRequestDTO
from visier_api_administration.models.users_update_api_request_dto import UsersUpdateAPIRequestDTO
from visier_api_administration.models.users_update_api_user_dto import UsersUpdateAPIUserDTO
